@@ -1,9 +1,6 @@
-summary.MClatent<-function(object,...){
-  if(!is.null(object$call))
-  {
-    cat("Call:\n")
-    print(object$call)
-  }
+summary.MClatent<-function(object,...){ 
+cat("Call:\n")
+print(object$call)
 cat("\nCoefficients:\n")
 
 cat("\n Be - Parameters affecting the logit for the initial probabilities:\n")
@@ -14,10 +11,10 @@ if(is.null(object$seBe)==FALSE){
 }
 
 cat("\n Ga - Parameters affecting the logit for the transition probabilities:\n")
-print(round(object$Ga,4))
+print(round(object$Ga,4))	
 if(is.null(object$seGa)==FALSE){
 	cat("\n Standard errors for Ga:\n")
-	print(round(object$seGa,4))
-}
+	print(round(object$seGa,4))		
+}	
 
-}
+}
\ No newline at end of file
